gtr_pub_df.RdThis function extracts publication information, number of journal articles published in a particular journal per year
gtr_pub_df(url)
| url | project URL from gtr.ukri.org |
|---|
Dataframe with project_id, journal title, year, number of publications in that journal for a particular year